/*
 * AMA sideband data context
 * Copyright (C) 2023 VeriSilicon Holdings Co., Ltd.
 *
 * This file is part of FFmpeg.
 *
 * FFmpeg is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * FFmpeg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with FFmpeg; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

/**
 * @file
 * AMA sideband data context, used for sd_read and sd_write filter
 */

#ifndef AMA_SIDEDATA_COMMON_H
#define AMA_SIDEDATA_COMMON_H

#include "libavutil/imgutils.h"
#include "libavutil/internal.h"
#include "libavutil/opt.h"
#include "libavutil/frame.h"
#include "avfilter.h"
#include "internal.h"
#include "video.h"
#include "vpi_api.h"
#include "libavutil/mastering_display_metadata.h"
#include "libavutil/hdr_dynamic_metadata.h"

#define NUM_AVFRAME_SIDEDATA_TYPE (AV_FRAME_DATA_SB_ML_TENSOR + 1)
#define AV_FRAME_DATA_AMA_ML_TYPE_START AV_FRAME_DATA_SB_ML_ROI
#define AV_FRAME_DATA_AMA_ML_TYPE_END AV_FRAME_DATA_SB_ML_TENSOR

#define OFFSET(x) offsetof(AmaSdContext, x)
#define ML_HEAD_SIZE sizeof(AmaSdMLHeader)
#define COMMON_HEAD_SIZE sizeof(AmaSdCommonHeader)

typedef struct _AmaSdMLHeader{
    uint32_t width;                          /*sidedata width*/
    uint32_t height;                         /*sidedata height*/
    uint32_t channel;                        /*sidedata channel*/
    uint32_t batch;                          /*sidedata batch*/
    enum VpiNbgLayoutEnum layout;            /*sidedata layout*/
} AmaSdMLHeader;

typedef struct _AmaSdCommonHeader{
    uint32_t frameId;
    enum AVFrameSideDataType type;
    uint32_t data_size;
} AmaSdCommonHeader;

typedef struct _AmaSdContext {
    const AVClass *class;
    unsigned char *sb_file;
    FILE *sb_fp;
    AmaSdCommonHeader com_header;
    AmaSdMLHeader ml_header;
    uint32_t frameId;
} AmaSdContext;

#endif /* AMA_SIDEDATA_COMMON_H */